import{P as f}from"./PlayerNavbar.f4e17c73.js";import{d as g,e3 as h,e4 as c,f as y,g as k,r as v,K as b,u as a,c as w,F as L,a as C,b as I,o as i,Q as N}from"./index.fd66f361.js";import{u as V}from"./workspaceStore.2a009b33.js";import"./userStore.749badae.js";import"./metadata.79a32911.js";import"./PhWebhooksLogo.vue.cd20e8b0.js";import"./LoadingOutlined.8d67646f.js";import"./PhSignOut.vue.99f479e8.js";import"./index.f35aec9d.js";import"./Avatar.02092cfa.js";import"./runnerData.4633183b.js";import"./url.32de1d47.js";import"./colorHelpers.ffad89ea.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="9c4e35f0-d99d-4dd8-9549-83afd304d3cf",o._sentryDebugIdIdentifier="sentry-dbid-9c4e35f0-d99d-4dd8-9549-83afd304d3cf")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,n=y(null),u=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},_=k(()=>!!c().meta.hideLogin);return(r,s)=>{const m=v("RouterView");return i(),b("div",x,[a(t).state.workspace?(i(),w(f,{key:0,"current-path":a(d),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.035169ee.js.map
