import{u as w,A as r,a as A}from"./Avatar.02092cfa.js";import{d as I,a9 as $,g as k,aE as D,bO as E,aw as G,ay as O,b as l,cH as _,ac as c}from"./index.fd66f361.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="f1737ea4-bdd9-456f-981e-c4d5df7b687b",e._sentryDebugIdIdentifier="sentry-dbid-f1737ea4-bdd9-456f-981e-c4d5df7b687b")}catch{}})();const j=()=>({prefixCls:String,maxCount:Number,maxStyle:{type:Object,default:void 0},maxPopoverPlacement:{type:String,default:"top"},maxPopoverTrigger:String,size:{type:[Number,String,Object],default:"default"},shape:{type:String,default:"circle"}}),N=I({compatConfig:{MODE:3},name:"AAvatarGroup",inheritAttrs:!1,props:j(),setup(e,n){let{slots:m,attrs:t}=n;const{prefixCls:y,direction:h}=$("avatar",e),d=k(()=>`${y.value}-group`),[g,b]=w(y);return D(()=>{const i={size:e.size,shape:e.shape};A(i)}),()=>{const{maxPopoverPlacement:i="top",maxCount:a,maxStyle:x,maxPopoverTrigger:S="hover",shape:C}=e,v={[d.value]:!0,[`${d.value}-rtl`]:h.value==="rtl",[`${t.class}`]:!!t.class,[b.value]:!0},P=E(m,e),s=G(P).map((o,f)=>O(o,{key:`avatar-key-${f}`})),u=s.length;if(a&&a<u){const o=s.slice(0,a),f=s.slice(a,u);return o.push(l(_,{key:"avatar-popover-key",content:f,trigger:S,placement:i,overlayClassName:`${d.value}-popover`},{default:()=>[l(r,{style:x,shape:C},{default:()=>[`+${u-a}`]})]})),g(l("div",c(c({},t),{},{class:v,style:t.style}),[o]))}return g(l("div",c(c({},t),{},{class:v,style:t.style}),[s]))}}}),p=N;r.Group=p;r.install=function(e){return e.component(r.name,r),e.component(p.name,p),e};export{p as G};
//# sourceMappingURL=index.f35aec9d.js.map
