import{O as d}from"./userStore.749badae.js";import{d as l,J as i,K as c,b as t,w as n,u as o,o as u,az as s,d6 as f,d5 as b}from"./index.fd66f361.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="1244a230-fc32-40e4-a1c7-6036bb80a0eb",e._sentryDebugIdIdentifier="sentry-dbid-1244a230-fc32-40e4-a1c7-6036bb80a0eb")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new d().loginCallback()}),(a,r)=>(u(),c("div",null,[t(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),t(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.66f64ef6.js.map
