import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.fd40095d.js";import{d as f,e3 as m,e4 as b,K as g,b as y,u as n,o as w,Q as k}from"./index.fd66f361.js";import{u as h}from"./workspaceStore.2a009b33.js";import"./userStore.749badae.js";import"./CircularLoading.0fc86793.js";import"./Logo.94a004d7.js";import"./string.973cdadd.js";import"./index.89096276.js";import"./runnerData.4633183b.js";import"./url.32de1d47.js";import"./colorHelpers.ffad89ea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="13a0f5fc-7477-40d6-9ab5-1a4c7f194a74",e._sentryDebugIdIdentifier="sentry-dbid-13a0f5fc-7477-40d6-9ab5-1a4c7f194a74")}catch{}})();const v={class:"runner"},I=f({__name:"Login",setup(e){const o=m(),t=b(),a=h(),_=async()=>{const{redirect:r,...s}=t.query;if(r){await o.push({path:r,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(r,s)=>{var c,p,u,d,i;return w(),g("div",v,[y(l,{"logo-url":(p=(c=n(a).state.workspace)==null?void 0:c.logoUrl)!=null?p:void 0,"brand-name":(u=n(a).state.workspace)==null?void 0:u.brandName,locale:(i=(d=n(a).state.workspace)==null?void 0:d.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const K=k(I,[["__scopeId","data-v-cb33c596"]]);export{K as default};
//# sourceMappingURL=Login.c82685fd.js.map
