import{O as d}from"./userStore.749badae.js";import{d as l,J as u,K as i,b as t,w as n,u as o,o as c,az as s,d6 as f,d5 as _}from"./index.fd66f361.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a526264c-ae7e-4535-9fb3-14aae5e85af3",e._sentryDebugIdIdentifier="sentry-dbid-a526264c-ae7e-4535-9fb3-14aae5e85af3")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new d().logoutCallback()}),(a,r)=>(c(),i("div",null,[t(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),t(o(_),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.e60dd6e8.js.map
