import{d as t,o,K as s,b as a,u as c,br as r,Q as _}from"./index.fd66f361.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="1bc6bc87-cbdb-4db2-a6f7-4d64650decfb",e._sentryDebugIdIdentifier="sentry-dbid-1bc6bc87-cbdb-4db2-a6f7-4d64650decfb")}catch{}})();const i={class:"centered"},b=t({__name:"LoadingContainer",setup(e){return(n,d)=>(o(),s("div",i,[a(c(r))]))}});const p=_(b,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.d5bd0812.js.map
