import{_ as p}from"./TasksView.vue_vue_type_script_setup_true_lang.3d50e61b.js";import{L as c}from"./tasksController.c343a60e.js";import{d as f,f as u,c as _,w as t,o as m,b as s,u as o,d6 as y,az as i,bM as b,da as k,Q as w}from"./index.fd66f361.js";import{C as g}from"./ContentLayout.c509f1dd.js";import{a as T}from"./ant-design.01b4eef9.js";import"./metadata.79a32911.js";import"./PhWebhooksLogo.vue.cd20e8b0.js";import"./string.973cdadd.js";import"./index.fe7b9d7b.js";import"./dayjs.2708615b.js";import"./gateway.c8676992.js";import"./popupNotifcation.45eb3465.js";import"./linters.25176e5c.js";import"./asyncComputed.c1514d75.js";import"./scripts.5832e54b.js";import"./record.8d6523fc.js";import"./polling.5fe64c23.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a6d1e490-ae22-4b23-989d-4fd4b0a51338",e._sentryDebugIdIdentifier="sentry-dbid-a6d1e490-ae22-4b23-989d-4fd4b0a51338")}catch{}})();const x=f({__name:"Tasks",setup(e){const a=new c,r=u(null);async function l(){var n;await T("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(d,n)=>(m(),_(g,null,{default:t(()=>[s(o(k),{justify:"space-between",align:"center"},{default:t(()=>[s(o(y),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(b),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(p,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const $=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{$ as default};
//# sourceMappingURL=Tasks.0d95e4d6.js.map
