import{C as p}from"./controller.9d4d4aa4.js";import{d as i,e4 as n,c as s,u as m,o as a}from"./index.fd66f361.js";import{_ as d}from"./View.vue_vue_type_script_setup_true_lang.2b97faf9.js";import"./gateway.c8676992.js";import"./popupNotifcation.45eb3465.js";import"./fetch.c880a606.js";import"./record.8d6523fc.js";import"./PhPencil.vue.22f5fd0d.js";import"./SaveButton.72b214ec.js";import"./UnsavedChangesHandler.c9ee5110.js";import"./ExclamationCircleOutlined.06153509.js";import"./CrudView.fa86e359.js";import"./router.26c95d47.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.3a6d45c1.js";import"./url.32de1d47.js";import"./PhDotsThreeVertical.vue.cd7ec533.js";import"./Badge.7cfeacae.js";import"./index.13458abe.js";import"./index.fe7b9d7b.js";import"./asyncComputed.c1514d75.js";import"./polling.5fe64c23.js";import"./omniChatStore.4b72ae26.js";import"./index.89096276.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="0fe04562-02d8-4b83-ac56-e46f645da288",o._sentryDebugIdIdentifier="sentry-dbid-0fe04562-02d8-4b83-ac56-e46f645da288")}catch{}})();const F=i({__name:"EnvVars",setup(o){const e=n().params.projectId,t=new p(e);return(c,f)=>(a(),s(d,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{F as default};
//# sourceMappingURL=EnvVars.2fa85bf4.js.map
