import{L as n}from"./Logo.94a004d7.js";import{d as a,o as r,c as d,u as c}from"./index.fd66f361.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="c5cd8c7d-fe5a-4746-b4b4-bcc35600c3c1",e._sentryDebugIdIdentifier="sentry-dbid-c5cd8c7d-fe5a-4746-b4b4-bcc35600c3c1")}catch{}})();const i="/assets/logo.0faadfa2.svg",l=a({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,t)=>{var o;return r(),d(n,{"image-url":c(i),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{l as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.4658ce04.js.map
