import{d as i,eo as c,g as r,o as a,K as t,F as d,ec as g,eb as p,Q as u}from"./index.fd66f361.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="500416e5-b019-485d-a24b-19753611e43e",e._sentryDebugIdIdentifier="sentry-dbid-500416e5-b019-485d-a24b-19753611e43e")}catch{}})();const _={class:"logo"},m=["src","alt"],f=i({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;c(o=>({"4521d904":n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),l=r(()=>`${s.brandName} Logo`);return(o,b)=>(a(),t("div",_,[o.imageUrl?(a(),t("img",{key:0,class:"logo-img",src:o.imageUrl,alt:l.value},null,8,m)):d("",!0),o.hideText?d("",!0):(a(),t("span",{key:1,class:g(o.size)},p(o.brandName),3))]))}});const h=u(f,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.94a004d7.js.map
