import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.4658ce04.js";import{B as y}from"./BaseLayout.97a37605.js";import{d as l,a6 as m,bY as b,Q as u,aT as v,aU as g,o as _,K as h,a as s,N as n,e4 as w,e3 as S,J as k,c as L,w as a,b as i,u as x}from"./index.fd66f361.js";import{u as B}from"./editor.b1112dd9.js";import{b as I}from"./index.92873ed6.js";import"./Logo.94a004d7.js";import"./userStore.749badae.js";import"./workspaceStore.2a009b33.js";import"./runnerData.4633183b.js";import"./url.32de1d47.js";import"./colorHelpers.ffad89ea.js";import"./linters.25176e5c.js";import"./asyncComputed.c1514d75.js";import"./index.f35aec9d.js";import"./Avatar.02092cfa.js";import"./index.13458abe.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b5497948-881c-4d2e-9e84-6f4296cce4fd",e._sentryDebugIdIdentifier="sentry-dbid-b5497948-881c-4d2e-9e84-6f4296cce4fd")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(o)}}});const P={class:"v-spinner"};function D(e,o,r,c,d,p){return v((_(),h("div",P,[s("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),s("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),s("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u($,[["render",D],["__scopeId","data-v-06538001"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const o=w(),r=S(),c=B();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),r.replace(t.pathname+t.search)}function p(){const t=o.query["api-key"];if(typeof t=="string")return t}return k(async()=>{const t=p();if(!t){r.push({name:"error"});return}await c.createLogin(t).then(d),r.push({name:"workspace"})}),(t,z)=>(_(),L(y,null,{navbar:a(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:a(()=>[i(f)]),_:1})]),content:a(()=>[s("div",R,[i(K)])]),_:1}))}});const W=u(j,[["__scopeId","data-v-944edebb"]]);export{W as default};
//# sourceMappingURL=ProjectLogin.3a9e2ebb.js.map
