import{m as a,n,T as r,p as o,P as d,C as p,M as c,s as m,q as s,t as f,v as u,x as g,y}from"./index.fd66f361.js";import{s as b}from"./userStore.749badae.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.2d1d3e8c.js";import{a as i}from"./workspaceStore.2a009b33.js";import"./PlayerConfigProvider.6c23896e.js";import"./colorHelpers.ffad89ea.js";import"./index.19aeeb1f.js";import"./runnerData.4633183b.js";import"./url.32de1d47.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="6ac3b4f1-46ed-45dc-82a3-0a670d346bee",t._sentryDebugIdIdentifier="sentry-dbid-6ac3b4f1-46ed-45dc-82a3-0a670d346bee")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const t=a(),e=n({render:()=>f(l)});r.init(),o(e,i),w.init(),e.use(i),e.use(t),e.use(d),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",c),e.component("Message",m),s(e,u),s(e,g),s(e,y)})();
//# sourceMappingURL=player.4b38e0f6.js.map
