import{B as e}from"./BaseLayout.97a37605.js";import{d as a,e4 as n,r as s,c,w as r,o as d,b as i,u as f}from"./index.fd66f361.js";import{N as u,_ as b}from"./Navbar.47180d12.js";import"./OmniChat.9a729faa.js";import"./gateway.c8676992.js";import"./popupNotifcation.45eb3465.js";import"./AbstraLogo.vue_vue_type_script_setup_true_lang.4658ce04.js";import"./Logo.94a004d7.js";import"./uuid.0988391e.js";import"./PhClockCounterClockwise.vue.d18f1684.js";import"./omniChatStore.4b72ae26.js";import"./record.8d6523fc.js";import"./LoadingOutlined.8d67646f.js";import"./columns.a93ffaa0.js";import"./string.973cdadd.js";import"./linters.25176e5c.js";import"./asyncComputed.c1514d75.js";import"./controller.a402f323.js";import"./workspaces.5564e380.js";import"./runnerData.4633183b.js";import"./url.32de1d47.js";import"./colorHelpers.ffad89ea.js";import"./index.f303a37e.js";import"./validations.9d3f6d16.js";import"./metadata.79a32911.js";import"./PhWebhooksLogo.vue.cd20e8b0.js";import"./controller.9d4d4aa4.js";import"./fetch.c880a606.js";import"./PhPencil.vue.22f5fd0d.js";import"./project.196732bf.js";import"./requirements.56f3bf59.js";import"./object.1a8ef115.js";import"./scripts.5832e54b.js";import"./PhCopySimple.vue.c5a3fe52.js";import"./index.959eaebd.js";import"./CollapsePanel.6e31af79.js";import"./Avatar.02092cfa.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.fe7e55b8.js";import"./PhArrowCounterClockwise.vue.064f9df6.js";import"./PhFilePy.vue.bcd13229.js";import"./PhChats.vue.569b8d96.js";import"./PhRocket.vue.3a58daa3.js";import"./PhPackage.vue.8c770904.js";import"./userStore.749badae.js";import"./polling.5fe64c23.js";import"./PhArrowSquareOut.vue.761d1db3.js";import"./PhDotsThree.vue.cae130ab.js";import"./PhSignOut.vue.99f479e8.js";import"./PhSparkle.vue.8254c822.js";import"./editor.b1112dd9.js";import"./workspaceStore.2a009b33.js";import"./index.13458abe.js";import"./CloseCircleOutlined.c1bfba2b.js";import"./CheckCircleFilled.2aa45a91.js";import"./index.89096276.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="bff79b71-9dde-414a-b345-94d743abc94c",t._sentryDebugIdIdentifier="sentry-dbid-bff79b71-9dde-414a-b345-94d743abc94c")}catch{}})();const yt=a({__name:"Workspace",setup(t){const o=n();return(p,_)=>{const m=s("RouterView");return d(),c(e,null,{navbar:r(()=>[i(u,{"page-title":f(o).meta.title},null,8,["page-title"])]),content:r(()=>[i(m)]),chat:r(()=>[i(b)]),_:1})}}});export{yt as default};
//# sourceMappingURL=Workspace.eb22814d.js.map
