import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.3d50e61b.js";import{R as f}from"./tasksController.c343a60e.js";import{d as b,e4 as _,g,K as y,b as w,w as k,u as n,c as I,F as T,aL as v,o as l,az as B,d6 as j}from"./index.fd66f361.js";import"./gateway.c8676992.js";import{a as x,B as C}from"./build.0c536c07.js";import{P as D}from"./project.196732bf.js";import"./columns.a93ffaa0.js";import{a as R}from"./asyncComputed.c1514d75.js";import"./metadata.79a32911.js";import"./PhWebhooksLogo.vue.cd20e8b0.js";import"./ant-design.01b4eef9.js";import"./string.973cdadd.js";import"./index.fe7b9d7b.js";import"./dayjs.2708615b.js";import"./linters.25176e5c.js";import"./scripts.5832e54b.js";import"./record.8d6523fc.js";import"./polling.5fe64c23.js";import"./popupNotifcation.45eb3465.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="36ff2c39-ae01-4b5c-abc1-4f157e6a49f1",e._sentryDebugIdIdentifier="sentry-dbid-36ff2c39-ae01-4b5c-abc1-4f157e6a49f1")}catch{}})();const U=b({__name:"Tasks",setup(e){const a=_().params.projectId,c=new f(a),{result:o}=R(async()=>{const r=(await x.list(a)).find(d=>d.latest);if(!r)return null;const[p,u]=await Promise.all([C.get(r.id),D.get(a)]);return{buildSpec:p,project:u}}),i=g(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(l(),y(v,null,[w(n(j),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(l(),I(m,{key:0,class:"tasks",api:n(c),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.6bcf0f01.js.map
