import{d as i,c as p,w as n,o as m,b as d,u as t}from"./index.fd66f361.js";import"./linters.25176e5c.js";import{W as s}from"./workspaces.5564e380.js";import{C as a}from"./ContentLayout.c509f1dd.js";import{E as f}from"./controller.9d4d4aa4.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.2b97faf9.js";import"./asyncComputed.c1514d75.js";import"./runnerData.4633183b.js";import"./url.32de1d47.js";import"./colorHelpers.ffad89ea.js";import"./record.8d6523fc.js";import"./gateway.c8676992.js";import"./popupNotifcation.45eb3465.js";import"./fetch.c880a606.js";import"./PhPencil.vue.22f5fd0d.js";import"./SaveButton.72b214ec.js";import"./UnsavedChangesHandler.c9ee5110.js";import"./ExclamationCircleOutlined.06153509.js";import"./CrudView.fa86e359.js";import"./router.26c95d47.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.3a6d45c1.js";import"./PhDotsThreeVertical.vue.cd7ec533.js";import"./Badge.7cfeacae.js";import"./index.13458abe.js";import"./index.fe7b9d7b.js";import"./polling.5fe64c23.js";import"./omniChatStore.4b72ae26.js";import"./index.89096276.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d87b06dc-8819-415d-adf7-2f3101f5f83b",o._sentryDebugIdIdentifier="sentry-dbid-d87b06dc-8819-415d-adf7-2f3101f5f83b")}catch{}})();const H=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(e,u)=>(m(),p(a,null,{default:n(()=>[d(c,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{H as default};
//# sourceMappingURL=EnvVarsEditor.48a9f82b.js.map
