import{i as k}from"./metadata.79a32911.js";import{W as h}from"./Watermark.ab6d4815.js";import{F as b}from"./PhArrowSquareOut.vue.761d1db3.js";import{d as w,e3 as v,g as x,f as C,u as e,K as m,b as p,w as r,F as z,o as a,c as n,az as f,d2 as y,aL as D,ea as I,da as _,ei as F,eb as L,ec as T,Q as B}from"./index.fd66f361.js";import{u as H}from"./workspaceStore.2a009b33.js";import"./index.1d759dd8.js";import{L as N}from"./LoadingOutlined.8d67646f.js";import{C as S}from"./Card.e007ce72.js";import"./PhWebhooksLogo.vue.cd20e8b0.js";import"./userStore.749badae.js";import"./runnerData.4633183b.js";import"./url.32de1d47.js";import"./colorHelpers.ffad89ea.js";import"./TabPane.e5cfdd05.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="225581e0-d082-4e01-8763-5b7c838ab158",o._sentryDebugIdIdentifier="sentry-dbid-225581e0-d082-4e01-8763-5b7c838ab158")}catch{}})();const V={key:0,class:"home-container"},W=w({__name:"Home",setup(o){const i=v(),l=H(),u=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(d=>d.id!=="home"))||[]}),c=C(null),g=async(s,d)=>{c.value=d,await i.push({path:`/${s}`}),c.value=null};return(s,d)=>e(l).state.workspace?(a(),m("div",V,[p(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(a(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(" There are no forms available for you. ")]),_:1})):(a(!0),m(D,{key:1},I(u.value,t=>(a(),n(e(S),{key:t.id,class:T(["form-card",{loading:c.value===t.id}]),"body-style":{cursor:"pointer"},onClick:E=>g(t.path,t.id)},{default:r(()=>[p(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(a(),n(F(e(k)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(L(t.name),1)]),_:2},1024),c.value!==t.id?(a(),n(e(b),{key:0,size:"20"})):(a(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(h,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):z("",!0)}});const Y=B(W,[["__scopeId","data-v-060376d1"]]);export{Y as default};
//# sourceMappingURL=Home.cb49ffb6.js.map
