import{O as s,R as c}from"./OmniChat.9a729faa.js";import{d as a,e4 as i,o as d,c as f,u as n}from"./index.fd66f361.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d416f658-48a6-4c98-9c76-3c96c8f76e9e",e._sentryDebugIdIdentifier="sentry-dbid-d416f658-48a6-4c98-9c76-3c96c8f76e9e")}catch{}})();const _=a({__name:"ConsoleOmniChat",setup(e){const t=i().params.projectId,r=new c(t);return(p,u)=>(d(),f(s,{"ai-chat-repository":n(r),environment:{origin:"console",projectId:n(t)}},null,8,["ai-chat-repository","environment"]))}});export{_};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.c67ef781.js.map
