import{P as f}from"./record.8d6523fc.js";import{e as r,f as a}from"./index.fd66f361.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ea0625ca-878f-4d79-b432-d539ec5e64f0",e._sentryDebugIdIdentifier="sentry-dbid-ea0625ca-878f-4d79-b432-d539ec5e64f0")}catch{}})();const i=new f,b=r("omniChat",()=>{const e=a(!1),t=a(!1),n=()=>{t.value=!0},s=()=>{t.value=!1},o=()=>{e.value=!0,n()},u=()=>{e.value=!1,s()};return{isOpen:e,isInputFocused:t,focusInput:n,blurInput:s,open:o,close:u,toggle:()=>{e.value?u():o()}}});export{i as o,b as u};
//# sourceMappingURL=omniChatStore.4b72ae26.js.map
