import{G as s,dv as i,dw as c}from"./index.fd66f361.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6de3aaf5-65d3-4f85-9245-edb9ad82fef7",e._sentryDebugIdIdentifier="sentry-dbid-6de3aaf5-65d3-4f85-9245-edb9ad82fef7")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:d}=i(c),y=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:d,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(d.name,d),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{y as D,r as M,a as Q,d as R,t as W};
//# sourceMappingURL=dayjs.2708615b.js.map
