import{cF as n}from"./index.fd66f361.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="b61d4a34-f82b-418a-a3c2-2fdf45b3690a",e._sentryDebugIdIdentifier="sentry-dbid-b61d4a34-f82b-418a-a3c2-2fdf45b3690a")}catch{}})();const o=(e,r,d)=>{n.error({message:e,description:r,onClick:d})};export{o as p};
//# sourceMappingURL=popupNotifcation.45eb3465.js.map
